@@ -8,7 +8,6 @@ import shlex
 import netifaces
 import socket
 import os
-from datetime import datetime, timedelta
 
 from kfsd.apps.core.common.logger import Logger, LogLevel
 from kfsd.apps.core.exceptions.exec import ExecExceptionHandler
@@ -132,17 +131,3 @@ class System:
     def api_key(len):
         api_key_bytes = secrets.token_bytes(int(len / 2))
         return binascii.hexlify(api_key_bytes).decode("utf-8")
-
-    @staticmethod
-    @ExecExceptionHandler(logger)
-    def future_time(dateconfig, format="%m/%d/%Y, %H:%M:%S %p"):
-        dt = datetime.now()
-        td = timedelta(**dateconfig)
-        newtime = dt + td
-        return newtime.strftime(format)
-
-    @staticmethod
-    @ExecExceptionHandler(logger)
-    def convert_datetime_str(date_str, format="%m/%d/%Y, %H:%M:%S %p"):
-        date_obj = datetime.strptime(date_str, format)
-        return date_obj
