@@ -1,4 +1,4 @@
-from drf_spectacular.utils import extend_schema_view
+from drf_spectacular.utils import extend_schema_view, extend_schema
 from rest_framework.decorators import action
 from rest_framework.renderers import JSONRenderer
 from rest_framework.views import Response
@@ -14,6 +14,7 @@ class OutpostModelViewSet(CustomModelViewSet):
     queryset = Outpost.objects.all()
     serializer_class = OutpostViewModelSerializer
 
+    @extend_schema(**OutpostDoc.send_all_view())
     @action(
         detail=False,
         methods=["get"],
@@ -24,4 +25,4 @@ class OutpostModelViewSet(CustomModelViewSet):
         queryset = Outpost.objects.all()
         for obj in queryset:
             send_msg.delay(obj.id)
-        return Response({"status": "ok"})
+        return Response({"detail": "ok"})
